# massphotometry: A Python Package for Mass Photometry Analysis

This package provides tools for mass photometry data analysis. 

## Current Functionality

In its initial release, `massphotometry` provides functions for the following:

*   **Reading MP Files:** Functionality to read and parse .mp (mass photometry) data files.
*   **Metadata Handling:** Tools to extract, and convert metadata from .mp files.

Future versions will add methods to extract the mass distribution from the measurement.

## Installation

To install `massphotometry`, ensure you have Python 3.10 or higher.

**Install the package from PyPI:**
```shell
pip install massphotometry
```

**Upgrade the pacakge**
```shell
pip install --upgrade massphotometry
```
